@@ -50,7 +50,7 @@ impl ArschitekZeroEmulator {
     pub fn new(executable_data: Vec<u8>) -> Self {
         let mut executable_data = executable_data;
         let mut registers = [0; 16];
-        executable_data.resize(1 << (u16::BITS * 2), 0);
+        executable_data.resize((1 << u16::BITS) * 2, 0);
         registers[14] = u16::MAX;
         ArschitekZeroEmulator {
             ip: 0,
